#!/bin/bash
#

source ${PRODUCTS}/setup
OS=`uname`
if [ ${OS} = "Darwin" ]
then
    flvr=`ups flavor -2`
else
    flvr=`ups flavor`
fi

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

thisdir=`pwd`
pdir=${thisdir}/${flvr}-gcc45
pver=2.7.2
upsver=v2_7_2

echo "Building python for flavor ${flvr}"

setup gcc v4_5_1

gccver=`gcc --version | head -1 | cut -f3 -d" " | cut -f1-2 -d"."`
gccfullver=`gcc --version | head -1 | cut -f3 -d" "`
if [ ${gccver} = "4.5" ]
then
  echo " OK - gcc version is ${gccfullver}"
else
  echo "ERROR: wrong gcc version ${gccfullver}"
  exit 1
fi

mkdir -p ${pdir}/build
if [ ! -d ${pdir}/build ]
then
   echo "ERROR: failed to create ${pdir}/build"
   exit 1
fi

set -x

cd ${pdir}/build
${thisdir}/source/Python-${pver}/configure --prefix=${pdir} --enable-shared
make
make install

set +x

# replace idle, pydoc, and smtpd.py with the scripts which use #!/usr/bin/env python
if [ ! -d ${pdir}/bin ]
then
   echo "ERROR: failed to create ${pdir}/bin"
   echo "       Something is very wrong"
   exit 1
fi
cd ${pdir}/bin
cp -p ${thisdir}/source/Python-${pver}/Tools/scripts/2to3 .
cp -p ${thisdir}/source/Python-${pver}/Tools/scripts/pydoc .
cp -p ${thisdir}/source/Python-${pver}/Tools/scripts/idle .
cp -p ${thisdir}/source/Python-${pver}/Lib/smtpd.py .
mv python2.7-config python2.7-config.bak
cat python2.7-config.bak | sed 's%^#!.*python2.7$%#!/usr/bin/env python%' > python2.7-config
chmod +x python2.7-config
cd ${pdir}/lib/pkgconfig
mv python-2.7.pc python-2.7.pc.bak
cat python-2.7.pc.bak | sed 's%^prefix=.*$%prefix=${PYTHONHOME}%' > python-2.7.pc

if [ ${OS} = "Darwin" ]
then
   ups declare python ${upsver} -r python/${upsver} -2 -m python.table -q gcc45
else 
   ups declare python ${upsver} -r python/${upsver} -4 -m python.table -q gcc45
fi

# this should not complain
setup python ${upsver} -q gcc45
echo "python is installed at ${PYTHONHOME}"

exit 0
